Coverage for Bio.Nexus: 100%

# Coverage for Bio.Nexus : 100%

## 1 statements 1 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 | # This code is part of the Biopython distribution and governed by its # license. Please see the LICENSE file that should have been included # as part of this package. """The Bio.Nexus contains a NEXUS file parser and objects to model this data."""